@@ -6,9 +6,9 @@
  * Date        : 2009-05-04
  * Description : Various operations on images
  *
- * Copyright (C) 2002-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2002-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
+ * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -56,6 +56,7 @@
 #include "loadingcacheinterface.h"
 #include "queuemgrwindow.h"
 #include "thumbnailloadthread.h"
+#include "fileactionmngr.h"
 
 namespace Digikam
 {
@@ -100,7 +101,7 @@ void ImageViewUtilities::rename(const KUrl& imageUrl, const QString& newName)
     DIO::rename(info, newName);
 }
 
-bool ImageViewUtilities::deleteImages(const QList<ImageInfo>& infos, bool deletePermanently)
+bool ImageViewUtilities::deleteImages(const QList<ImageInfo>& infos, const DeleteMode deleteMode)
 {
     if (infos.isEmpty())
     {
@@ -115,22 +116,27 @@ bool ImageViewUtilities::deleteImages(const QList<ImageInfo>& infos, bool delete
 
     DeleteDialog dialog(m_widget);
 
-    if (!dialog.confirmDeleteList(urlList,
-                                  DeleteDialogMode::Files,
-                                  deletePermanently ?
-                                  DeleteDialogMode::NoChoiceDeletePermanently :
-                                  DeleteDialogMode::NoChoiceTrash))
+    DeleteDialogMode::DeleteMode deleteDialogMode = DeleteDialogMode::NoChoiceTrash;
+    if (deleteMode==ImageViewUtilities::DeletePermanently)
+    {
+        deleteDialogMode = DeleteDialogMode::NoChoiceDeletePermanently;
+    }
+    if (!dialog.confirmDeleteList(
+                urlList,
+                DeleteDialogMode::Files,
+                deleteDialogMode
+            ))
     {
         return false;
     }
 
-    bool useTrash = !dialog.shouldDelete();
-
+    const bool useTrash = !dialog.shouldDelete();
     DIO::del(infos, useTrash);
+
     return true;
 }
 
-void ImageViewUtilities::deleteImagesDirectly(const QList<ImageInfo>& infos, bool useTrash)
+void ImageViewUtilities::deleteImagesDirectly(const QList<ImageInfo>& infos, const DeleteMode deleteMode)
 {
     // This method deletes the selected items directly, without confirmation.
     // It is not used in the default setup.
@@ -139,6 +145,7 @@ void ImageViewUtilities::deleteImagesDirectly(const QList<ImageInfo>& infos, boo
     {
         return;
     }
+    const bool useTrash = (deleteMode==ImageViewUtilities::DeleteUseTrash);
     DIO::del(infos, useTrash);
 }
 
@@ -301,4 +308,45 @@ void ImageViewUtilities::openInEditor(const ImageInfo& info, const QList<ImageIn
     KWindowSystem::activateWindow(imview->winId());
 }
 
+namespace
+{
+bool lessThanByTimeForImageInfo(const ImageInfo& a, const ImageInfo& b)
+{
+    return a.dateTime() < b.dateTime();
+}
+}
+
+void ImageViewUtilities::createGroupByTimeFromInfoList(const ImageInfoList& imageInfoList)
+{
+    QList<ImageInfo> groupingList = imageInfoList;
+    // sort by time
+    qStableSort(groupingList.begin(), groupingList.end(), lessThanByTimeForImageInfo);
+
+    QList<ImageInfo>::iterator it, it2;
+    for (it = groupingList.begin(); it != groupingList.end(); )
+    {
+        const ImageInfo& leader = *it;
+        QList<ImageInfo> group;
+        QDateTime time = it->dateTime();
+        for (it2 = it + 1; it2 != groupingList.end(); ++it2)
+        {
+            if (abs(time.secsTo(it2->dateTime())) < 2)
+            {
+                group << *it2;
+            }
+            else
+            {
+                break;
+            }
+        }
+        // increment to next item not put in the group
+        it = it2;
+
+        if (!group.isEmpty())
+        {
+            FileActionMngr::instance()->addToGroup(leader, group);
+        }
+    }
+}
+
 } // namespace Digikam
