@@ -6,8 +6,8 @@
  * Date        : 2004-12-06
  * Description : Black and White conversion tool.
  *
- * Copyright (C) 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2006-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * Copyright (C) 2006-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -57,13 +57,12 @@ using namespace KDcrawIface;
 namespace DigikamColorImagePlugin
 {
 
-class BWSepiaTool::BWSepiaToolPriv
+class BWSepiaTool::Private
 {
 
 public:
 
-    BWSepiaToolPriv() :
-        destinationPreviewData(0),
+    Private() :
         bwsepiaSettings(0),
         previewWidget(0),
         gboxSettings(0)
@@ -73,27 +72,27 @@ public:
     static const QString configHistogramChannelEntry;
     static const QString configHistogramScaleEntry;
 
-    uchar*               destinationPreviewData;
-
     BWSepiaSettings*     bwsepiaSettings;
 
     ImageRegionWidget*   previewWidget;
 
     EditorToolSettings*  gboxSettings;
 };
-const QString BWSepiaTool::BWSepiaToolPriv::configGroupName("convertbw Tool");
-const QString BWSepiaTool::BWSepiaToolPriv::configHistogramChannelEntry("Histogram Channel");
-const QString BWSepiaTool::BWSepiaToolPriv::configHistogramScaleEntry("Histogram Scale");
+
+const QString BWSepiaTool::Private::configGroupName("convertbw Tool");
+const QString BWSepiaTool::Private::configHistogramChannelEntry("Histogram Channel");
+const QString BWSepiaTool::Private::configHistogramScaleEntry("Histogram Scale");
 
 // -----------------------------------------------------------------------------------
 
-BWSepiaTool::BWSepiaTool(QObject* parent)
-    : EditorToolThreaded(parent), d(new BWSepiaToolPriv)
+BWSepiaTool::BWSepiaTool(QObject* const parent)
+    : EditorToolThreaded(parent), d(new Private)
 {
     setObjectName("convertbw");
     setToolName(i18n("Black and White"));
     setToolIcon(SmallIcon("bwtonal"));
     setToolHelp("blackandwhitetool.anchor");
+    setInitPreview(true);
 
     // -------------------------------------------------------------
 
@@ -112,11 +111,10 @@ BWSepiaTool::BWSepiaTool(QObject* parent)
                                 EditorToolSettings::Load|
                                 EditorToolSettings::SaveAs);
 
-    ImageIface iface(0, 0);
-    d->bwsepiaSettings = new BWSepiaSettings(d->gboxSettings->plainPage(), iface.getOriginalImg());
+    ImageIface iface;
+    d->bwsepiaSettings = new BWSepiaSettings(d->gboxSettings->plainPage(), iface.original());
 
     setToolSettings(d->gboxSettings);
-    init();
 
     // -------------------------------------------------------------
 
@@ -124,18 +122,11 @@ BWSepiaTool::BWSepiaTool(QObject* parent)
             this, SLOT(slotTimer()));
 
     connect(d->previewWidget, SIGNAL(signalResized()),
-            this, SLOT(slotEffect()));
-
-    slotTimer();
+            this, SLOT(slotPreview()));
 }
 
 BWSepiaTool::~BWSepiaTool()
 {
-    if (d->destinationPreviewData)
-    {
-        delete [] d->destinationPreviewData;
-    }
-
     delete d;
 }
 
@@ -178,10 +169,10 @@ void BWSepiaTool::slotResetSettings()
 {
     d->bwsepiaSettings->resetToDefault();
     d->gboxSettings->histogramBox()->histogram()->reset();
-    slotEffect();
+    slotPreview();
 }
 
-void BWSepiaTool::prepareEffect()
+void BWSepiaTool::preparePreview()
 {
     BWSepiaContainer settings = d->bwsepiaSettings->settings();
 
@@ -191,43 +182,35 @@ void BWSepiaTool::prepareEffect()
     setFilter(new BWSepiaFilter(&preview, this, settings));
 }
 
-void BWSepiaTool::putPreviewData()
+void BWSepiaTool::setPreviewImage()
 {
     DImg preview = filter()->getTargetImage();
     d->previewWidget->setPreviewImage(preview);
 
     // Update histogram.
 
-    if (d->destinationPreviewData)
-    {
-        delete [] d->destinationPreviewData;
-    }
-
-    d->destinationPreviewData = preview.copyBits();
-    d->gboxSettings->histogramBox()->histogram()->updateData(d->destinationPreviewData,
-            preview.width(), preview.height(), preview.sixteenBit(),
-            0, 0, 0, false);
+    d->gboxSettings->histogramBox()->histogram()->updateData(preview.copy(), DImg(), false);
 }
 
 void BWSepiaTool::prepareFinal()
 {
     BWSepiaContainer settings = d->bwsepiaSettings->settings();
 
-    ImageIface iface(0, 0);
-    setFilter(new BWSepiaFilter(iface.getOriginalImg(), this, settings));
+    ImageIface iface;
+    setFilter(new BWSepiaFilter(iface.original(), this, settings));
 }
 
-void BWSepiaTool::putFinalData()
+void BWSepiaTool::setFinalImage()
 {
-    ImageIface iface(0, 0);
-    iface.putOriginalImage(i18n("Convert to Black and White"), filter()->filterAction(), filter()->getTargetImage().bits());
+    ImageIface iface;
+    iface.setOriginal(i18n("Convert to Black and White"), filter()->filterAction(), filter()->getTargetImage());
 }
 
 void BWSepiaTool::slotLoadSettings()
 {
     d->bwsepiaSettings->loadSettings();
     d->gboxSettings->histogramBox()->histogram()->reset();
-    slotEffect();
+    slotPreview();
 }
 
 void BWSepiaTool::slotSaveAsSettings()
