@@ -6,8 +6,8 @@
  * Date        : 2009-10-26
  * Description : a class that manages painting histograms
  *
- * Copyright (C) 2009 by Johannes Wienke <languitar at semipol dot de>
- * Copyright (C) 2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009      by Johannes Wienke <languitar at semipol dot de>
+ * Copyright (C) 2011-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -43,13 +43,12 @@
 namespace Digikam
 {
 
-class HistogramPainter::HistogramPainterPriv
+class HistogramPainter::Private
 {
 
 public:
 
-    HistogramPainterPriv(HistogramPainter* q) :
-        q(q),
+    explicit Private(HistogramPainter* const q) :
         histogram(0),
         widgetToInitFrom(0),
         scale(LogScaleHistogram),
@@ -58,20 +57,18 @@ public:
         selectionMin(0.0),
         selectionMax(0.0),
         showColorGuide(false),
-        showXGrid(true)
-    {}
-
-private:
-
-    HistogramPainter* q;
+        showXGrid(true),
+        q(q)
+    {
+    }
 
 public:
 
     double calculateMax()
     {
         int segments = histogram->getHistogramSegments();
-        int startSeg = (int)(HISTOGRAM_CALC_CUTOFF_MIN * (segments-1));
-        int endSeg   = (int)(HISTOGRAM_CALC_CUTOFF_MAX * (segments-1));
+        int startSeg = (int)(HISTOGRAM_CALC_CUTOFF_MIN * (segments - 1));
+        int endSeg   = (int)(HISTOGRAM_CALC_CUTOFF_MAX * (segments - 1));
         double max   = 0.0;
 
         switch (scale)
@@ -161,7 +158,7 @@ public:
         {
             case LinScaleHistogram:
             {
-                return qMin((int) ((pixmapHeight * value) / max), pixmapHeight);
+                return qMin((int)((pixmapHeight * value) / max), pixmapHeight);
             }
 
             case LogScaleHistogram:
@@ -177,7 +174,7 @@ public:
                     return 0;
                 }
 
-                return qMin((int) ((pixmapHeight * log(value)) / max), pixmapHeight);
+                return qMin((int)((pixmapHeight * log(value)) / max), pixmapHeight);
             }
 
             default:
@@ -248,6 +245,7 @@ public:
 
         QColor pColor;
         QColor bColor;
+
         switch (channelType)
         {
             case GreenChannel:
@@ -345,7 +343,7 @@ public:
             ybPrev = yb;
         }
 
-        curveRed.lineTo(wWidth - 2, wHeight - 1);
+        curveRed.lineTo(wWidth - 2, wHeight - 1);        
         curveRed.lineTo(1, wHeight - 1);
         curveRed.closeSubpath();
         curveGreen.lineTo(wWidth - 2, wHeight - 1);
@@ -471,7 +469,7 @@ public:
             p1.drawLine(xGuide, 0, xGuide, bufferPixmap.height());
 
             QString string = i18n("x:%1", guidePos);
-            QFontMetrics fontMt( string );
+            QFontMetrics fontMt(string);
             QRect rect     = fontMt.boundingRect(0, 0, bufferPixmap.width(), bufferPixmap.height(), 0, string);
             p1.setPen(QPen(Qt::red, 1, Qt::SolidLine));
             rect.moveTop(1);
@@ -479,7 +477,7 @@ public:
             if (xGuide < bufferPixmap.width() / 2)
             {
                 rect.moveLeft(xGuide);
-                p1.fillRect(rect, QBrush(QColor(250, 250, 255)) );
+                p1.fillRect(rect, QBrush(QColor(250, 250, 255)));
                 p1.drawRect(rect);
                 rect.moveLeft(xGuide + 3);
                 p1.drawText(rect, Qt::AlignLeft, string);
@@ -487,7 +485,7 @@ public:
             else
             {
                 rect.moveRight(xGuide);
-                p1.fillRect(rect, QBrush(QColor(250, 250, 255)) );
+                p1.fillRect(rect, QBrush(QColor(250, 250, 255)));
                 p1.drawRect(rect);
                 rect.moveRight(xGuide - 3);
                 p1.drawText(rect, Qt::AlignRight, string);
@@ -511,10 +509,14 @@ public:
     bool              showColorGuide;
     bool              showXGrid;
     DColor            colorGuide;
+
+private:
+
+    HistogramPainter* q;
 };
 
-HistogramPainter::HistogramPainter(QObject* parent)
-    : QObject(parent), d(new HistogramPainterPriv(this))
+HistogramPainter::HistogramPainter(QObject* const parent)
+    : QObject(parent), d(new Private(this))
 {
 }
 
@@ -523,7 +525,7 @@ HistogramPainter::~HistogramPainter()
     delete d;
 }
 
-void HistogramPainter::setHistogram(ImageHistogram* histogram)
+void HistogramPainter::setHistogram(ImageHistogram* const histogram)
 {
     d->histogram = histogram;
 }
@@ -577,7 +579,7 @@ void HistogramPainter::disableHistogramGuide()
     d->showColorGuide = false;
 }
 
-void HistogramPainter::initFrom(QWidget* widget)
+void HistogramPainter::initFrom(QWidget* const widget)
 {
     d->widgetToInitFrom = widget;
 }
