@@ -454,7 +454,7 @@ bool ProgressManager::addProgressItem(ProgressItem* const t, ProgressItem* const
     else
     {
         KMessageBox::error(kapp->activeWindow(),
-                           i18n("A tool named \"%1\" is already running....", t->label()));
+                           i18n("A tool identified as \"%1\" is already running....", t->id()));
         t->setComplete();
         return false;
     }
