@@ -62,7 +62,6 @@ namespace Digikam
 
 class Canvas;
 class DImageHistory;
-class DLogoAction;
 class EditorTool;
 class EditorStackView;
 class ExposureSettingsContainer;
@@ -140,7 +139,6 @@ protected:
 
     KActionMenu*              m_selectToolsAction;
 
-    DLogoAction*              m_animLogo;
     KMenu*                    m_contextMenu;
     EditorStackView*          m_stackView;
     Canvas*                   m_canvas;
@@ -329,7 +327,7 @@ private:
     void quitWaitingLoop();
     void showSideBars(bool visible);
     void showThumbBar(bool visible);
-    void showCustomizedView(bool visible);
+    void customizedFullScreenMode(bool set);
     bool thumbbarVisibility() const;
     void setColorManagedViewIndicatorToolTip(bool available, bool cmv);
     void setUnderExposureToolTip(bool uei);
