@@ -7,6 +7,7 @@
  * Description : setup tab for image versioning
  *
  * Copyright (C) 2010 by Martin Klapetek <martin dot klapetek at gmail dot com>
+ * Copyright (C) 2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,7 +38,7 @@ class SetupVersioning : public QScrollArea
 
 public:
 
-    SetupVersioning(QWidget* parent = 0);
+    explicit SetupVersioning(QWidget* const parent = 0);
     ~SetupVersioning();
 
     void applySettings();
@@ -56,8 +57,8 @@ private Q_SLOTS:
 
 private:
 
-    class SetupVersioningPriv;
-    SetupVersioningPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 } // namespace Digikam
