@@ -70,7 +70,7 @@ class Manager : public QObject
 
 public:
 
-    Manager(QObject* const parent=0);
+    explicit Manager(QObject* const parent = 0);
     ~Manager();
 
     bool checkBinaries();
